@@ -1,58 +1,6 @@
-#' Downstream methods for Salmon and Alevin expression data
-#'
-#' This package provides statistical methods and other tools for
-#' working with Salmon and Alevin quantification of RNA-seq data.
-#' In particular, it contains the Swish non-parametric method for
-#' detecting differential transcript expression (DTE). Swish can
-#' also be used to detect differential gene expresion (DGE).
-#'
-#' The main functions are:
-#' \itemize{
-#' \item \code{\link{scaleInfReps}} - scaling transcript or gene expression data
-#' \item \code{\link{labelKeep}} - labelling which features have sufficient counts
-#' \item \code{\link{swish}} - perform non-parametric differential analysis
-#' \item Plots, e.g., \code{\link{plotMASwish}}, \code{\link{plotInfReps}}
-#' \item \code{\link{isoformProportions}} - convert counts to isoform proportions
-#' \item \code{\link{makeInfReps}} - create pseudo-inferential replicates
-#' \item \code{\link{splitSwish}} - split Swish analysis across jobs with Snakemake
-#' }
-#' 
-#' All software-related questions should be posted to the Bioconductor Support Site:
-#' 
-#' \url{https://support.bioconductor.org}
-#'
-#' The code can be viewed at the GitHub repository,
-#' which also lists the contributor code of conduct:
-#'
-#' \url{https://github.com/mikelove/fishpond}
-#' 
-#' @references
-#'
-#' Swish method:
-#' 
-#' Zhu, A., Srivastava, A., Ibrahim, J.G., Patro, R., Love, M.I. (2019)
-#' Nonparametric expression analysis using inferential replicate counts.
-#' Nucleic Acids Research.
-#' \url{https://doi.org/10.1093/nar/gkz622}
-#'
-#' Compression, makeInfReps and splitSwish:
-#'
-#' Van Buren, S., Sarkar, H., Srivastava, A., Rashid, N.U.,
-#' Patro, R., Love, M.I. (2020)
-#' Compression of quantification uncertainty for scRNA-seq counts.
-#' bioRxiv.
-#' \url{https://doi.org/10.1101/2020.07.06.189639}
-#' 
-#' @author Anqi Zhu, Avi Srivastava, Joseph G. Ibrahim, Rob Patro, Michael I. Love
-#' 
-#' @docType package
-#' @name fishpond-package
-#' @aliases fishpond-package
-#' @keywords package
-NULL
-
-#' swish: SAMseq With Inferential Samples Helps
+#' Swish method: differential expression accounting for inferential uncertainty
 #'
+#' The Swish method, or "SAMseq With Inferential Samples Helps".
 #' Performs non-parametric inference on rows of \code{y} for
 #' various experimental designs. See References for details.
 #'
@@ -85,15 +33,17 @@ NULL
 #' 'Note on factor levels')
 #' @param cov the name of the covariate for adjustment.
 #' If provided a stratified Wilcoxon in performed.
-#' Cannot be used with \code{pair} (unless using \code{cor})
+#' Cannot be used with \code{pair}, unless using
+#' either \code{interaction} or \code{cor}
 #' @param pair the name of the pair variable, which should be the
 #' number of the pair. Can be an integer or factor.
 #' If specified, a signed rank test is used
 #' to build the statistic. All samples across \code{x} must be
-#' pairs if this is specified. Cannot be used with \code{cov}
-#' (unless using \code{cor})
+#' pairs if this is specified. Cannot be used with \code{cov},
+#' unless using either \code{interaction} or \code{cor}
 #' @param interaction logical, whether to perform a test of an interaction
-#' between \code{x} and \code{cov}. See Details.
+#' between \code{x} and \code{cov}. Can use \code{pair} or not.
+#' See Details.
 #' @param cor character, whether to compute correlation of \code{x}
 #' with the log counts, and signifance testing on the correlation
 #' as a test statistic.
@@ -171,18 +121,6 @@ NULL
 #' plotInfReps(y, 1, "condition")
 #' plotInfReps(y, 3, "condition")
 #' plotInfReps(y, 5, "condition")
-#'
-#' @importFrom graphics plot points segments rect abline title axis legend
-#' @importFrom stats median quantile qnorm rpois runif rnbinom var cor
-#' @importFrom utils head tail capture.output read.table write.table read.csv
-#' @importFrom methods is as
-#' @importFrom SummarizedExperiment SummarizedExperiment
-#' assayNames assayNames<- assay assay<- assays assays<-
-#' colData colData<- mcols mcols<-
-#' @importFrom S4Vectors DataFrame metadata metadata<-
-#' @importFrom gtools permutations
-#' @importFrom Matrix rowSums
-#' @importFrom matrixStats rowRanks rowMedians rowVars rowQuantiles
 #' 
 #' @export
 swish <- function(y, x, cov=NULL, pair=NULL,
@@ -228,7 +166,7 @@ swish <- function(y, x, cov=NULL, pair=NULL,
   }
   if (qvaluePkg == "samr") {
     if (!requireNamespace("samr", quietly=TRUE)) {
-      stop("first install the 'samr' package")
+      stop("first install the 'samr' CRAN package")
     }
   }
   
